fireworks.user_objects.queue_adapters package — FireWorks 1.4.4 documentation

# fireworks.user_objects.queue_adapters package

## Subpackages

- fireworks.user_objects.queue_adapters.tests package
  - Submodules
  - fireworks.user_objects.queue_adapters.tests.test_common_adapter module
  - Module contents

## Submodules

## fireworks.user_objects.queue_adapters.common_adapter module

class `fireworks.user_objects.queue_adapters.common_adapter.` `CommonAdapter`(q_type, q_name=None, template_file=None, **kwargs)

  Bases: `fireworks.queue.queue_adapter.QueueAdapterBase`

  An adapter that works on most PBS (including derivatives such as TORQUE), SGE, and SLURM queues.

  `default_q_commands` = {u'PBS': {u'submit_cmd': u'qsub', u'status_cmd': u'qstat'}, u'LoadSharingFacility': {u'submit_cmd': u'bsub', u'status_cmd': u'bjobs'}, u'SGE': {u'submit_cmd': u'qsub', u'status_cmd': u'qstat'}, u'SLURM': {u'submit_cmd': u'sbatch', u'status_cmd': u'squeue'}, u'Cobalt': {u'submit_cmd': u'qsub', u'status_cmd': u'qstat'}, u'LoadLeveler': {u'submit_cmd': u'llsubmit', u'status_cmd': u'llq'}}
  classmethod `from_dict`(m_dict)
  `get_njobs_in_queue`(username=None)

    returns the number of jobs currently in the queu efor the user

    Parameters: | username – (str) the username of the jobs to count (default is to autodetect)
    Returns: | (int) number of jobs in the queue

  `submit_to_queue`(script_file)

    submits the job to the queue and returns the job id

    Parameters: | script_file – (str) name of the script file to use (String)
    Returns: | (int) job_id

  `to_dict`(*args, **kwargs)

## fireworks.user_objects.queue_adapters.pbs_newt_adapter module

class `fireworks.user_objects.queue_adapters.pbs_newt_adapter.` `PBSAdapterNEWT`

  Bases: `fireworks.queue.queue_adapter.QueueAdapterBase`

  A special PBS adapter that works via the NEWT interface (https://newt.nersc.gov) Only intended for job submission via the RESTful NEWT web interface.

  `defaults` = {}
  `get_njobs_in_queue`(username=None)
  `q_name` = u'pbs_newt'
  `resource` = u'carver'
  `submit_cmd` = u''
  `submit_to_queue`(script_file)
  `template_file` = u'/Users/ajain/Documents/code_matgen/fireworks/fireworks/user_objects/queue_adapters/PBS_template.txt'

## Module contents